==> ogre-next-2.2.4-1-x86_64.pkg.tar.zst: usr/share/OGRE/docs/api/html/_setting_up_ogre.js <==
var _setting_up_ogre =
[
    [ "Windows", "_setting_up_ogre_windows.html", [
      [ "Requirements", "_setting_up_ogre_windows.html#RequirementsWindows", null ],
      [ "Downloading Ogre", "_setting_up_ogre_windows.html#DownloadingOgreWindows", null ],
      [ "Building Dependencies", "_setting_up_ogre_windows.html#BuildingDependenciesWindows", null ],
      [ "Building Ogre", "_setting_up_ogre_windows.html#BuildingOgreWindows", null ]
    ] ],
    [ "Linux", "_setting_up_ogre_linux.html", [
      [ "Requirements", "_setting_up_ogre_linux.html#RequirementsLinux", null ],
      [ "Downloading Ogre", "_setting_up_ogre_linux.html#DownloadingOgreLinux", null ],
      [ "Building Dependencies", "_setting_up_ogre_linux.html#BuildingDependenciesLinux", null ],
      [ "Building Ogre", "_setting_up_ogre_linux.html#BuildingOgreLinux", null ],
      [ "Setting Up Ogre with QtCreator", "_setting_up_ogre_linux.html#SettingUpOgreWithQtCreatorLinux", null ]
    ] ],
    [ "iOS", "_setting_up_ogre_i_o_s.html", [
      [ "Requirements", "_setting_up_ogre_i_o_s.html#Requirements_iOS", null ],
      [ "Downloading Ogre", "_setting_up_ogre_i_o_s.html#DownloadingOgre_iOS", null ],
      [ "Building Ogre", "_setting_up_ogre_i_o_s.html#BuildingOgre_iOS", null ]
    ] ],
    [ "macOS", "_setting_up_ogre_mac_o_s.html", [
      [ "Install cmake", "_setting_up_ogre_mac_o_s.html#autotoc_md12", null ],
      [ "Install dependencies", "_setting_up_ogre_mac_o_s.html#autotoc_md13", null ],
      [ "Build Ogre", "_setting_up_ogre_mac_o_s.html#autotoc_md14", null ],
      [ "Build offline version of the docs", "_setting_up_ogre_mac_o_s.html#autotoc_md15", null ]
    ] ]
];

==> ogre-next-2.3.1-1-x86_64.pkg.tar.zst: usr/share/OGRE/docs/api/html/_setting_up_ogre.js <==
var _setting_up_ogre =
[
    [ "Windows", "_setting_up_ogre_windows.html", [
      [ "Requirements", "_setting_up_ogre_windows.html#RequirementsWindows", null ],
      [ "Downloading Ogre", "_setting_up_ogre_windows.html#DownloadingOgreWindows", null ],
      [ "Building Dependencies", "_setting_up_ogre_windows.html#BuildingDependenciesWindows", null ],
      [ "Building Ogre", "_setting_up_ogre_windows.html#BuildingOgreWindows", null ]
    ] ],
    [ "Linux", "_setting_up_ogre_linux.html", [
      [ "Requirements", "_setting_up_ogre_linux.html#RequirementsLinux", null ],
      [ "Downloading Ogre", "_setting_up_ogre_linux.html#DownloadingOgreLinux", null ],
      [ "Building Dependencies", "_setting_up_ogre_linux.html#BuildingDependenciesLinux", null ],
      [ "Building Ogre", "_setting_up_ogre_linux.html#BuildingOgreLinux", null ],
      [ "Setting Up Ogre with QtCreator", "_setting_up_ogre_linux.html#SettingUpOgreWithQtCreatorLinux", null ]
    ] ],
    [ "iOS", "_setting_up_ogre_i_o_s.html", [
      [ "Requirements", "_setting_up_ogre_i_o_s.html#Requirements_iOS", null ],
      [ "Downloading Ogre", "_setting_up_ogre_i_o_s.html#DownloadingOgre_iOS", null ],
      [ "Building Ogre", "_setting_up_ogre_i_o_s.html#BuildingOgre_iOS", null ]
    ] ],
    [ "macOS", "_setting_up_ogre_mac_o_s.html", [
      [ "Install cmake", "_setting_up_ogre_mac_o_s.html#autotoc_md12", null ],
      [ "Install dependencies", "_setting_up_ogre_mac_o_s.html#autotoc_md13", [
        [ "Install SDL2 using brew", "_setting_up_ogre_mac_o_s.html#autotoc_md14", null ]
      ] ],
      [ "Build Ogre", "_setting_up_ogre_mac_o_s.html#autotoc_md15", null ],
      [ "Build offline version of the docs", "_setting_up_ogre_mac_o_s.html#autotoc_md16", null ]
    ] ],
    [ "Android", "_setting_up_ogre_android.html", [
      [ "Requirements", "_setting_up_ogre_android.html#RequirementsAndroid", null ],
      [ "Downloading and building Ogre", "_setting_up_ogre_android.html#DownloadingOgreAndroid", null ],
      [ "Building Samples", "_setting_up_ogre_android.html#BuildingSamplesAndroid", null ]
    ] ]
];
